%global readers_dir %(pkg-config libpcsclite --variable=usbdropdir)

%define		main_version 3.99.5
%define		sub_version SP14

Name:		pcsc-cyberjack
Version:	%main_version.%sub_version
Release:	%mkrel 2
Summary:	PC/SC driver for REINER SCT cyberjack USB chipcard reader
License:	LGPLv2+
Group:		System/Kernel and hardware
URL:		http://www.reiner-sct.com/
Source0:	http://support.reiner-sct.de/downloads/LINUX/V%{main_version}_%{sub_version}/%{name}_%{main_version}final.%{sub_version}.tar.gz
# (doktor5000) useful hints on troubleshooting / debugging, taken from Fedora
Source1:	https://src.fedoraproject.org/rpms/pcsc-cyberjack/raw/master/f/%{name}-%{main_version}final.SP09-README-FEDORA
Source2:	libifd-cyberjack6.udev
# this patch replaces the obsoleted AC_PROG_LIBTOOLT macro with LT_INIT
# the patch is sent to upstream per email (20160528)
Patch0:		pcsc-cyberjack-3.99.5final.SP09-configure.patch
BuildRequires:	gcc
BuildRequires:	gcc-c++
BuildRequires:	pkgconfig(libpcsclite)
BuildRequires:	pkgconfig(libusb-1.0)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	readline-devel
BuildRequires:	sysfsutils-devel
# for macro definition:
BuildRequires:  pkgconfig(libsystemd)
Requires:	pcsc-lite
Requires:	udev

%description
REINER SCT cyberJack USB chip card reader user space driver.

This package includes the IFD driver for the cyberJack contactless (RFID)
and contact USB chipcard reader.

For more information regarding installation under Linux see the README.txt
in the documentation directory, esp. regarding compatibility with host
controllers.

For more information about the reader, software updates and a shop see
http://www.reiner-sct.com/


%prep
%setup -q -n %{name}-%{main_version}final.%{sub_version}
%autopatch -p1

install -pm 644 %{SOURCE1} README-MAGEIA.txt

install -pm 644 %{SOURCE2} debian/

%build
autoreconf -vfi

%configure --disable-static \
	--mandir=%{_mandir}/man8 \
	--enable-pcsc \
	--sysconfdir="%{_sysconfdir}" \
	--with-usbdropdir="%{readers_dir}" \
	--enable-release \
	--enable-udev \
	--enable-hal=no

%make_build

#manually build extra tools
%make_build -C tools/cjflash
%make_build -C tools/cjgeldkarte

pushd doc
iconv -f iso8859-1 -t utf-8 LIESMICH.txt > LIESMICH.txt.conv && mv -f LIESMICH.txt.conv LIESMICH.txt
iconv -f iso8859-1 -t utf-8 README.txt > README.txt.conv && mv -f README.txt.conv README.txt
popd

%install
%make_install

# cjflash and cjgeldkarte does not get installed automatically
%make_install -C tools/cjflash
%make_install -C tools/cjgeldkarte

#remove unneeded files
rm -f %{buildroot}%{_libdir}/cyberjack/pcscd_init.diff
rm -f %{buildroot}%{_libdir}/pcsc/drivers/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.la

mv %{buildroot}%{_sysconfdir}/cyberjack.conf.default %{buildroot}%{_sysconfdir}/cyberjack.conf

# udev rule based on the file from debian sub-folder
# we need the devices to be in group cyberjack
sed -i 's/GROUP="pcscd"/GROUP="cyberjack"/' debian/libifd-cyberjack6.udev
install -Dm 644 debian/libifd-cyberjack6.udev %{buildroot}%{_udevrulesdir}/93-cyberjack.rules


%pre
%_pre_groupadd cyberjack

%post
%udev_rules_update

%systemd_postun_with_restart pcscd.socket


%postun
%udev_rules_update

%systemd_postun_with_restart pcscd.socket


%files
# AUTHORS is 0 length and will not be packaged therefore
%doc etc/cyberjack.conf.default README-MAGEIA.txt ChangeLog
%doc doc/README.txt doc/README.pdf doc/README.html
%doc doc/LIESMICH.txt doc/LIESMICH.pdf doc/LIESMICH.html
%license COPYING COPYRIGHT.GPL COPYRIGHT.LGPL

%config(noreplace) %{_sysconfdir}/cyberjack.conf
%{_bindir}/cjflash
%{_bindir}/cjgeldkarte
%{_udevrulesdir}/93-cyberjack.rules
%{readers_dir}/libifd-cyberjack.bundle/Contents/Info.plist
%{readers_dir}/libifd-cyberjack.bundle/Contents/PkgInfo
%{readers_dir}/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.so
%{readers_dir}/libifd-cyberjack.bundle/Contents/Linux/libifd-cyberjack.so.*


%changelog
* Tue Mar 29 2022 umeabot <umeabot> 3.99.5.SP14-2.mga9
+ Revision: 1832256
- Mageia 9 Mass Rebuild

* Sat Jul 11 2020 daviddavid <daviddavid> 3.99.5.SP14-1.mga8
+ Revision: 1604806
- new version: 3.99.5.SP14

* Sun Feb 16 2020 umeabot <umeabot> 3.99.5.SP13-2.mga8
+ Revision: 1530583
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 02 2019 daviddavid <daviddavid> 3.99.5.SP13-1.mga8
+ Revision: 1436479
- new version: 3.99.5.SP13

* Sun Sep 23 2018 umeabot <umeabot> 3.99.5.SP08-4.mga7
+ Revision: 1300141
- Mageia 7 Mass Rebuild

* Mon Oct 09 2017 cjw <cjw> 3.99.5.SP08-3.mga7
+ Revision: 1170550
- patch2: fix build with gcc 7

* Sun Oct 16 2016 tv <tv> 3.99.5.SP08-2.mga6
+ Revision: 1061155
- BR systemd-devel for macro definition (mga#12027)

* Fri Jan 01 2016 doktor5000 <doktor5000> 3.99.5.SP08-1.mga6
+ Revision: 917662
- use %%configure2_5x instead of %%configure to fix build
- new version 3.99.5-SP08
- synced with Fedora
  o added helpful README from Fedora as README-MAGEIA.txt
  o use pkg-config to find correct target directory for pcsc drivers
  o install config as %%{_sysconfdir}/cyberjack.conf and not as .default
  o mark %%{_sysconfdir}/cyberjack.conf as %%config(noreplace)
- devices created by udev have to be in group "cyberjack", not in "pcscd"
  o create group cyberjack in %%post with rpm-helper if not existent
  o update udev rules database in %%post / %%postun
- restart pcsc.socket during uninstallation
- added -gui subpackage and conditional for it, disabled for now

* Wed Oct 15 2014 umeabot <umeabot> 3.99.5.SP03-6.mga5
+ Revision: 739335
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 3.99.5.SP03-5.mga5
+ Revision: 727545
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 3.99.5.SP03-4.mga5
+ Revision: 683373
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.99.5.SP03-3.mga4
+ Revision: 509250
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 cjw <cjw> 3.99.5.SP03-2.mga3
+ Revision: 363236
- patch1: fix build with glibc 2.17
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 23 2012 doktor5000 <doktor5000> 3.99.5.SP03-1.mga2
+ Revision: 200261
- fix license tag to LGPLv2+
- add %%sub_version to %%version
- use placeholders in %%files list
- imported package pcsc-cyberjack

